<!doctype html>
<html lang="en">
    <head>
        <meta charset="UTF-8" />
        <meta name="viewport" content="width=device-width, initial-scale=1.0" />
        <link
            rel="icon"
            type="image/png"
            href="data:image/png;base64,{{favicon_base64}}"
        />
        <title>{{title}}</title>
        <style>
            * {
                margin: 0;
                padding: 0;
                box-sizing: border-box;
            }
            body {
                font-family:
                    -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto,
                    Oxygen, Ubuntu, sans-serif;
                background-color: #ededf2;
                color: #1f1f1f;
                min-height: 100vh;
                display: flex;
                align-items: flex-start;
                justify-content: center;
                padding-top: 162px;
            }
            @media (prefers-color-scheme: dark) {
                body {
                    background-color: #000031;
                    color: #d1d5db;
                }
                .card {
                    background: #0f1b2a;
                    box-shadow: 0 1px 3px rgba(0, 0, 0, 0.3);
                }
            }
            .card {
                background: white;
                padding: 48px;
                border-radius: 12px;
                box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
                text-align: center;
                max-width: 402px;
                width: 90%;
            }
            .logo {
                height: 48px;
                margin-bottom: 32px;
            }
            .status-icon {
                width: 48px;
                height: 48px;
                margin-bottom: 16px;
            }
            .status-icon.success {
                color: #037f0c;
            }
            .status-icon.error {
                color: #d91515;
            }
            .message {
                font-size: 16px;
                line-height: 1.6;
                white-space: pre-line;
                color: #000000;
            }
        </style>
    </head>
    <body>
        <div class="card">
            <img
                class="logo"
                src="data:image/png;base64,{{logo_base64}}"
                alt="A-Alpha Bio"
            />
            <p>{{status_icon}}</p>
            <p class="message">{{message}}</p>
        </div>
    </body>
</html>
